from setuptools import setup

setup(name='notafunnytest',
      version='1.0.1',
      description='The least funny joke in the world',
      url='https://github.com/LorenzoPeve/notafunnytest',
      author='Lorenzo Peve',
      author_email='doesnotexist@gmail.com',
      license='MIT',
      packages=['notafunnytest'],
      classifiers=[
        "Programming Language :: Python :: 3",
        "Operating System :: OS Independent",
    ],
      zip_safe=False)